@@ -26,7 +26,7 @@ if(is_shop()) {
 get_header('shop');
 
 if(is_shop()) { ?>
-    <section class="full-width product-category shop-page" style="background-image: url();">
+    <section class="full-width product-category shop-page" style="background-image: url(<?= get_template_directory_uri() . '/dist/images/background/pilgrims-bg.png'; ?>);">
 
     <h1 class="shop-title text-center"><?= woocommerce_page_title(); ?></h1>
 <?php }
